# Galileo

A theme for [Maverick](https://github.com/AlanDecode/Maverick), designed for personal blog.

[![Actions Status](https://github.com/AlanDecode/Maverick-Theme-Galileo/workflows/Build/badge.svg)](https://github.com/AlanDecode/Maverick-Theme-Galileo/actions)

**Usage**

Set `template` in Maverick configuration file as bellow:

```python
template = {
    "name": "Galileo",
    "type": "git",
    "url": "https://github.com/AlanDecode/Maverick-Theme-Galileo.git",
    "branch": "latest"
}
```

or just set:

```python
template = "Galileo"
```

MIT © [AlanDecode](https://github.com/AlanDecode)
